@@ -1,7 +1,7 @@
 # -*- coding: latin-1 -*-
 
 """
-SimpleGUICS2Pygame package (June 27, 2013)
+SimpleGUICS2Pygame package (July 13, 2013)
 
 It is primarily a standard Python_ (2 **and** 3) module
 reimplementing the SimpleGUI particular module of CodeSkulptor_
@@ -11,7 +11,10 @@ Require Pygame_
 (except for the Timer class)
 (`Unofficial Windows Binaries`_).
 
-`Online HTML documentation`_ on `DragonSoft DS`_ website.
+Module simpleplot require matplotlib_ .
+
+
+`Online HTML documentation`_ on Read The Docs.
 
 Piece of SimpleGUICS2Pygame.
 https://bitbucket.org/OPiMedia/simpleguics2pygame
@@ -20,21 +23,21 @@ GPLv3 --- Copyright (C) 2013 Olivier Pirson
 http://www.opimedia.be/
 
 .. _CodeSkulptor: http://www.codeskulptor.org/
-.. _`DragonSoft DS`: http://www.opimedia.be/DS/SimpleGUICS2Pygame/
-.. _`Online HTML documentation`: http://www.opimedia.be/DS/SimpleGUICS2Pygame/doc_html/index.htm
+.. _`Online HTML documentation`: https://readthedocs.org/docs/simpleguics2pygame/en/latest/
 .. _Pygame: http://www.pygame.org/
 .. _Python: http://www.python.org/
 .. _`Unofficial Windows Binaries`: http://www.lfd.uci.edu/~gohlke/pythonlibs/#pygame
 
 Started on May 21, 2013
 
+v.01.00.00 --- July 13, 2013
 v.00.92.00 --- June 27, 2013
 v.00.91.00 --- June 23, 2013
 v.00.90.10 --- June 19, 2013
 v.00.90.00 --- June 13, 2013
 """
 
-_VERSION = '00.92.00'
+_VERSION = '01.00.00'
 """
 Version of simpleguics2pygame module.
 """
