@@ -4,7 +4,7 @@
 """
 script/SimpleGUICS2Pygame_check.py
 
-(June 23, 2013)
+(July 6, 2013)
 
 Piece of SimpleGUICS2Pygame.
 https://bitbucket.org/OPiMedia/simpleguics2pygame
@@ -28,6 +28,17 @@ python - version""", version)
 
     print()
 
+    try:
+        cmd = 'import matplotlib'
+
+        import matplotlib
+
+        print(cmd, 'ok - Version', matplotlib.__version__)
+    except Exception as e:
+        print(cmd, 'FAILED!', e)
+
+    print()
+
     try:
         cmd = 'import pygame'
 
@@ -93,3 +104,12 @@ python - version""", version)
         print(cmd, 'ok')
     except Exception as e:
         print(cmd, 'FAILED!', e)
+
+    try:
+        cmd = 'import SimpleGUICS2Pygame.simpleplot'
+
+        import SimpleGUICS2Pygame.simpleplot
+
+        print(cmd, 'ok')
+    except Exception as e:
+        print(cmd, 'FAILED!', e)
